@@ -15,25 +15,25 @@ def construct_default_scale(note: int, scale_type: str) -> list:
     return [(note+n)%12 or 12 for n in default_scales[scale_type]]
 
 # Converts notes in string form to their number equivalents, with A as key 1
-def str_scale_to_numbers(scale):
+def str_scale_to_numbers(scale: "list[str]") -> "list[int]":
     return sorted([notes.index(note.upper())+1 for note in scale])
 
 # Converts notes in number form to their string equivalents, with A as key 1
-def num_scale_to_strs(scale):
+def num_scale_to_strs(scale: "list[int]") -> "list[str]":
     return [notes[note-1] for note in sorted(scale)]
 
 # Converts note number to frequency
-def to_freq(note):
+def to_freq(note: int) -> float:
     return 27.5 * (2 ** ((note - 1) / 12))
 
 # Converts frequency to note number
-def to_note(freq):
+def to_note(freq: float) -> int:
     return round(log(freq/27.5, 2**(1/12))+1,4)
 
 # Get closest element to a target item in a list
-def get_closest(pool: list, target: int or float):
+def get_closest(pool: list, target: float) -> float:
     return min(pool, key=lambda x: abs(x-target))
 
 # Get all valid note frequencies given a scale of notes
-def construct_note_freqs(scale):
+def construct_note_freqs(scale: "list[int]") -> "list[float]":
     return [to_freq((12*i)+j) for i in range(8) for j in scale if 12*i+j<=88]
\ No newline at end of file
