@@ -2,6 +2,7 @@ import os
 modules_to_alias=["update_widgets","widgets_help","gorilla_clean","stk_swx","tuner"]
 
 def main():
+    os.system("pip3 -q install spl_widgets --upgrade")
     os.system("pip -q install spl_widgets --upgrade")
     zprofile = f"{os.getenv('HOME')}/.zprofile"
     with open(zprofile,"r") as reader:
@@ -14,7 +15,7 @@ def main():
                 newlines.append(line)
         
         for module in modules_to_alias:
-            alias_str = f'alias {module}="python3 -m spl_widgets {module}\n'
+            alias_str = f'alias {module}="python3 -m spl_widgets {module}" \n'
             newlines.append(alias_str)
 
     with open(zprofile, "w") as writer:
